@@ -78,3 +78,6 @@ PREVIEW_LENGTH_LIMIT = 10_000
 PREVIEW_LIMIT_SIZE = 2 * 1024 * 1024  # 2 MB
 
 MAX_CREDENTIALS_CACHE_SIZE = 30
+
+MULTIPART_UPLOAD_BLOCK_SIZE = 30 * 1024 * 1024  # 30 MB
+DOWNLOAD_BLOCK_SIZE = 30 * 1024 * 1024  # 30 MB
